import base64
from curtin import util
from curtin import paths
from curtin.log import LOG

CURTIN_HOOKS = base64.b64decode('''\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''').decode('utf-8')


def inject_curtin_hooks(target):
    hookfile = paths.target_path(target, '/curtin/curtin-hooks.py')
    LOG.info('HACK: injecting new curtin-hooks file: %s', hookfile)
    content = CURTIN_HOOKS
    util.write_file(hookfile, content, mode=0o755)
